@@ -6,6 +6,7 @@ from typing import TYPE_CHECKING, Any, List, Optional
 
 from ....utils.async_tools import check_canceled, threaded
 from ....utils.logging import LoggingDescriptor
+from ....utils.uri import Uri
 from ...common.decorators import language_id
 from ...common.lsp_types import (
     Diagnostic,
@@ -19,6 +20,7 @@ from ...common.text_document import TextDocument
 from ..configuration import AnalysisConfig
 from ..diagnostics.analyzer import Analyzer
 from ..diagnostics.entities import ArgumentDefinition
+from ..diagnostics.namespace import Namespace
 from ..utils.ast_utils import (
     HeaderAndBodyBlock,
     Token,
@@ -48,13 +50,27 @@ class RobotDiagnosticsProtocolPart(RobotLanguageServerProtocolPart):
         parent.diagnostics.collect.add(self.collect_unused_keyword_references)
         parent.diagnostics.collect.add(self.collect_unused_variable_references)
 
-        parent.diagnostics.collect_document_has_diagnostics.add(self.collect_document_has_diagnostics)
+        parent.documents_cache.namespace_invalidated.add(self.namespace_invalidated)
 
     @language_id("robotframework")
     @_logger.call
-    async def collect_document_has_diagnostics(self, sender: Any, document: TextDocument) -> bool:
-        namespace = await self.parent.documents_cache.get_namespace(document)
-        return namespace is None or await namespace.is_initialized() and await namespace.is_analyzed()
+    async def namespace_invalidated(self, sender: Any, namespace: Namespace) -> None:
+        if namespace.document is not None:
+            refresh = namespace.document.opened_in_editor
+
+            await self.parent.diagnostics.force_refresh_document(namespace.document, False)
+
+            if await namespace.is_initialized():
+                resources = (await namespace.get_resources()).values()
+                for r in resources:
+                    if r.library_doc.source:
+                        doc = await self.parent.documents.get(Uri.from_path(r.library_doc.source).normalized())
+                        if doc is not None:
+                            refresh |= doc.opened_in_editor
+                            await self.parent.diagnostics.force_refresh_document(doc, False)
+
+            if refresh:
+                await self.parent.diagnostics.refresh()
 
     @language_id("robotframework")
     @threaded()
@@ -311,12 +327,12 @@ class RobotDiagnosticsProtocolPart(RobotLanguageServerProtocolPart):
     @_logger.call
     async def collect_unused_variable_references(self, sender: Any, document: TextDocument) -> DiagnosticsResult:
         if not self.parent.diagnostics.workspace_loaded_event.is_set():
-            return DiagnosticsResult(self.collect_unused_keyword_references, None)
+            return DiagnosticsResult(self.collect_unused_variable_references, None)
 
         config = await self.parent.workspace.get_configuration(AnalysisConfig, document.uri)
 
         if not config.find_unused_references:
-            return DiagnosticsResult(self.collect_unused_keyword_references, [])
+            return DiagnosticsResult(self.collect_unused_variable_references, [])
 
         return await self._collect_unused_variable_references(document)
 
@@ -324,7 +340,7 @@ class RobotDiagnosticsProtocolPart(RobotLanguageServerProtocolPart):
         try:
             namespace = await self.parent.documents_cache.get_namespace(document)
             if namespace is None:
-                return DiagnosticsResult(self.collect_unused_keyword_references, None)
+                return DiagnosticsResult(self.collect_unused_variable_references, None)
 
             result: List[Diagnostic] = []
 
@@ -343,12 +359,12 @@ class RobotDiagnosticsProtocolPart(RobotLanguageServerProtocolPart):
                         )
                     )
 
-            return DiagnosticsResult(self.collect_unused_keyword_references, result)
+            return DiagnosticsResult(self.collect_unused_variable_references, result)
         except (asyncio.CancelledError, SystemExit, KeyboardInterrupt):
             raise
         except BaseException as e:
             return DiagnosticsResult(
-                self.collect_unused_keyword_references,
+                self.collect_unused_variable_references,
                 [
                     Diagnostic(
                         range=Range(
