@@ -7,6 +7,7 @@ import contextvars
 import functools
 import inspect
 import threading
+import time
 import weakref
 from collections import deque
 from concurrent.futures.thread import ThreadPoolExecutor
@@ -322,6 +323,9 @@ def run_coroutine_in_thread(
 
         ct = asyncio.current_task()
 
+        loop = asyncio.get_event_loop()
+        loop.slow_callback_duration = 10
+
         callback_added_event.wait(600)
 
         if ct is not None and result is not None:
@@ -335,28 +339,33 @@ def run_coroutine_in_thread(
         return await inner_task
 
     def run(coro: Callable[..., Coroutine[Any, Any, _T]], *args: Any, **kwargs: Any) -> _T:
-        loop = asyncio.new_event_loop()
 
         old_name = threading.current_thread().getName()
         threading.current_thread().setName(coro.__qualname__)
-
         try:
-            asyncio.set_event_loop(loop)
-
-            t = loop.create_task(create_inner_task(coro, *args, **kwargs), name=coro.__qualname__)
-
-            return loop.run_until_complete(t)
+            return asyncio.run(create_inner_task(coro, *args, **kwargs))
         finally:
-            try:
-                running_tasks = asyncio.all_tasks(loop)
-                if running_tasks:
-                    loop.run_until_complete(asyncio.gather(*running_tasks, return_exceptions=True))
+            threading.current_thread().setName(old_name)
 
-                loop.run_until_complete(loop.shutdown_asyncgens())
-            finally:
-                asyncio.set_event_loop(None)
-                loop.close()
-                threading.current_thread().setName(old_name)
+        # loop = asyncio.new_event_loop()
+
+        # try:
+        #     asyncio.set_event_loop(loop)
+
+        #     t = loop.create_task(create_inner_task(coro, *args, **kwargs), name=coro.__qualname__)
+
+        #     return loop.run_until_complete(t)
+        # finally:
+        #     try:
+        #         running_tasks = asyncio.all_tasks(loop)
+        #         if running_tasks:
+        #             loop.run_until_complete(asyncio.gather(*running_tasks, return_exceptions=True))
+
+        #         loop.run_until_complete(loop.shutdown_asyncgens())
+        #     finally:
+        #         asyncio.set_event_loop(None)
+        #         loop.close()
+        #         threading.current_thread().setName(old_name)
 
     cti = get_current_future_info()
     result = run_in_thread(run, coro, *args, **kwargs)
@@ -387,7 +396,7 @@ async def async_lock(lock: threading.RLock) -> AsyncGenerator[None, None]:
     start_time = time.monotonic()
     locked = lock.acquire(blocking=False)
     while not locked:
-        if time.monotonic() - start_time >= 20:
+        if time.monotonic() - start_time >= 1800:
             raise TimeoutError("Timeout waiting for lock")
 
         await asyncio.sleep(0.001)
@@ -430,12 +439,12 @@ class Event:
                     fut = self._waiters.popleft()
 
                     if not fut.done():
-                        if fut._loop == asyncio.get_running_loop():
+                        if fut.get_loop() == asyncio.get_running_loop():
                             if not fut.done():
                                 fut.set_result(True)
                         else:
 
-                            def s(w: asyncio.Future[Any], ev: threading.Event) -> None:
+                            def set_result(w: asyncio.Future[Any], ev: threading.Event) -> None:
                                 try:
                                     if not w.done():
                                         w.set_result(True)
@@ -445,10 +454,10 @@ class Event:
                             if not fut.done():
                                 done = threading.Event()
 
-                                fut._loop.call_soon_threadsafe(s, fut, done)
+                                fut.get_loop().call_soon_threadsafe(set_result, fut, done)
 
                                 if not done.wait(120):
-                                    raise TimeoutError("Callback timeout")
+                                    raise TimeoutError("Callback timeout.")
 
     def clear(self) -> None:
         with self._lock:
@@ -493,15 +502,15 @@ class Semaphore:
                 waiter = self._waiters.popleft()
 
                 if not waiter.done():
-                    if waiter._loop == asyncio.get_running_loop():
+                    if waiter.get_loop() == asyncio.get_running_loop():
                         if not waiter.done():
                             waiter.set_result(True)
                     else:
-                        if waiter._loop.is_running():
+                        if waiter.get_loop().is_running():
 
-                            def s(w: asyncio.Future[Any], ev: threading.Event) -> None:
+                            def set_result(w: asyncio.Future[Any], ev: threading.Event) -> None:
                                 try:
-                                    if w._loop.is_running() and not w.done():
+                                    if w.get_loop().is_running() and not w.done():
                                         w.set_result(True)
                                 finally:
                                     ev.set()
@@ -509,20 +518,28 @@ class Semaphore:
                             if not waiter.done():
                                 done = threading.Event()
 
-                                waiter._loop.call_soon_threadsafe(s, waiter, done)
+                                waiter.get_loop().call_soon_threadsafe(set_result, waiter, done)
 
-                                if not done.wait(120):
-                                    raise TimeoutError("Callback timeout")
+                                start = time.monotonic()
+                                while not done.is_set():
+
+                                    if time.monotonic() - start > 120:
+                                        raise TimeoutError("Can't set future result.")
+
+                                    await asyncio.sleep(0.001)
 
     def locked(self) -> bool:
         with self._lock:
             return self._value == 0
 
     async def acquire(self, timeout: Optional[float] = None) -> bool:
-        while self._value <= 0:
-            fut = create_sub_future()
+        while True:
             async with async_lock(self._lock):
+                if self._value > 0:
+                    break
+                fut = create_sub_future()
                 self._waiters.append(fut)
+
             try:
                 await asyncio.wait_for(fut, timeout)
             except asyncio.TimeoutError:
@@ -621,7 +638,6 @@ class OldLock:
         while not b:
             await asyncio.sleep(0)
             b = self._lock.acquire(blocking=False)
-
         try:
             yield None
         finally:
@@ -664,8 +680,6 @@ class OldLock:
             if self._waiters is None or len(self._waiters) == 0:
                 if self._locked:
                     self._locked = False
-                else:
-                    raise RuntimeError(f"Lock is not acquired ({len(self._waiters) if self._waiters else 0} waiters).")
 
         await self._wake_up_next()
 
@@ -681,16 +695,34 @@ class OldLock:
             if fut in self._waiters:
                 self._waiters.remove(fut)
 
-        def s() -> None:
-            if not fut.done():
-                fut.set_result(True)
-
-        if fut._loop == asyncio.get_running_loop():
+        if fut.get_loop() == asyncio.get_running_loop():
             if not fut.done():
                 fut.set_result(True)
         else:
-            if fut._loop.is_running():
-                fut._loop.call_soon_threadsafe(s)
+            if fut.get_loop().is_running():
+
+                def set_result(w: asyncio.Future[Any], ev: threading.Event) -> None:
+                    try:
+                        if w.get_loop().is_running() and not w.done():
+                            w.set_result(True)
+                    finally:
+                        ev.set()
+
+                if not fut.done():
+                    done = threading.Event()
+
+                    fut.get_loop().call_soon_threadsafe(set_result, fut, done)
+
+                    start = time.monotonic()
+                    while not done.is_set():
+
+                        if time.monotonic() - start > 120:
+                            raise TimeoutError("Can't set future result.")
+
+                        await asyncio.sleep(0.001)
+
+                    # if not done.wait(120):
+                    #     raise TimeoutError("Callback timeout.")
 
 
 class FutureInfo:
@@ -705,10 +737,10 @@ class FutureInfo:
             for t in self.children.copy():
                 if not t.done() and not t.cancelled():
 
-                    if t._loop == asyncio.get_running_loop():
+                    if t.get_loop() == asyncio.get_running_loop():
                         t.cancel()
                     else:
-                        t._loop.call_soon_threadsafe(t.cancel)
+                        t.get_loop().call_soon_threadsafe(t.cancel)
 
     def canceled(self) -> bool:
         task = self.task()
